summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h2
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c6
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h10
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c26
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h10
6 files changed, 28 insertions, 28 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c
index 1ac35d9c..80e07682 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/ortp.c
@@ -101,7 +101,7 @@ void ortp_scheduler_init()
sigset_t set;
sigemptyset(&set);
sigaddset(&set,SIGALRM);
- sigproctqmask(SIG_BLOCK,&set,NULL);
+ sigprocmask(SIG_BLOCK,&set,NULL);
#endif /* __hpux */
if (!g_thread_supported()) g_thread_init(NULL);
__ortp_scheduler=rtp_scheduler_new();
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h
index 7518e075..e7702000 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/rtpsession.h
@@ -177,7 +177,7 @@ struct _RtpSession
RtpSessionMode mode;
struct _RtpScheduler *sched;
guint32 flags;
- gint mask_pos; /* the position in the scheduler tqmask of RtpSession */
+ gint mask_pos; /* the position in the scheduler mask of RtpSession */
gpointer user_data;
/* telephony events extension */
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h
index 4dcd9afb..91cde6a9 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.h
@@ -29,13 +29,13 @@
struct _RtpScheduler {
RtpSession *list; /* list of scheduled sessions*/
- SessionSet all_sessions; /* tqmask of scheduled sessions */
- gint all_max; /* the highest pos in the all tqmask */
- SessionSet r_sessions; /* tqmask of sessions that have a recv event */
+ SessionSet all_sessions; /* mask of scheduled sessions */
+ gint all_max; /* the highest pos in the all mask */
+ SessionSet r_sessions; /* mask of sessions that have a recv event */
gint r_max;
- SessionSet w_sessions; /* tqmask of sessions that have a send event */
+ SessionSet w_sessions; /* mask of sessions that have a send event */
gint w_max;
- SessionSet e_sessions; /* tqmask of session that have error event */
+ SessionSet e_sessions; /* mask of session that have error event */
gint e_max;
gint max_sessions; /* the number of position in the masks */
/* GMutex *unblock_select_mutex; */
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h
index 8d166222..623b9d10 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.h
@@ -45,7 +45,7 @@ typedef fd_set ortp_fd_set;
do { \
unsigned int __i; \
ortp_fd_set *__arr = (s); \
- for (__i = 0; __i < sizeof (ortp_fd_set) / sizeof (ortp__fd_tqmask); ++__i) \
+ for (__i = 0; __i < sizeof (ortp_fd_set) / sizeof (ortp__fd_mask); ++__i) \
ORTP__FDS_BITS (__arr)[__i] = 0; \
} while (0)
#define ORTP_FD_SET(d, s) (ORTP__FDS_BITS (s)[ORTP__FDELT(d)] |= ORTP__FDMASK(d))
@@ -55,22 +55,22 @@ typedef fd_set ortp_fd_set;
/* The fd_set member is required to be an array of longs. */
-typedef long int ortp__fd_tqmask;
+typedef long int ortp__fd_mask;
/* Number of bits per word of `fd_set' (some code assumes this is 32). */
#define ORTP__FD_SETSIZE 1024
/* It's easier to assume 8-bit bytes than to get CHAR_BIT. */
-#define ORTP__NFDBITS (8 * sizeof (ortp__fd_tqmask))
+#define ORTP__NFDBITS (8 * sizeof (ortp__fd_mask))
#define ORTP__FDELT(d) ((d) / ORTP__NFDBITS)
-#define ORTP__FDMASK(d) ((ortp__fd_tqmask) 1 << ((d) % ORTP__NFDBITS))
+#define ORTP__FDMASK(d) ((ortp__fd_mask) 1 << ((d) % ORTP__NFDBITS))
/* fd_set for select and pselect. */
typedef struct
{
- ortp__fd_tqmask fds_bits[ORTP__FD_SETSIZE / ORTP__NFDBITS];
+ ortp__fd_mask fds_bits[ORTP__FD_SETSIZE / ORTP__NFDBITS];
# define ORTP__FDS_BITS(set) ((set)->fds_bits)
} ortp_fd_set;
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
index bee787a2..17ff6748 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
@@ -148,7 +148,7 @@ gpointer rtp_scheduler_schedule(gpointer psched)
g_mutex_unlock(sched->lock);
/* now while the scheduler is going to sleep, the other threads can compute their
- result tqmask and see if they have to leave, or to wait for next tick*/
+ result mask and see if they have to leave, or to wait for next tick*/
//g_message("scheduler: sleeping.");
timer->timer_do();
sched->time_+=sched->timer_inc;
@@ -174,7 +174,7 @@ void rtp_scheduler_add_session(RtpScheduler *sched, RtpSession *session)
if (sched->max_sessions==0){
g_error("rtp_scheduler_add_session: max_session=0 !");
}
/* find a free pos in the session tqmask*/
for (i=0;i<sched->max_sessions;i++){
if (!ORTP_FD_ISSET(i,&sched->all_sessions.rtpset)){
session->mask_pos=i;
@@ -229,7 +229,7 @@ void rtp_scheduler_remove_session(RtpScheduler *sched, RtpSession *session)
}
}
rtp_session_unset_flag(session,RTP_SESSION_IN_SCHEDULER);
/* delete the bit in the tqmask */
session_set_clr(&sched->all_sessions,session);
rtp_scheduler_unlock(sched);
}
@@ -174,7 +174,7 @@ void rtp_scheduler_add_session(RtpScheduler *sched, RtpSession *session)
g_error("rtp_scheduler_add_session: max_session=0 !");
}
- /* find a free pos in the session tqmask*/
+ /* find a free pos in the session mask*/
for (i=0;i<sched->max_sessions;i++){
if (!ORTP_FD_ISSET(i,&sched->all_sessions.rtpset)){
@@ -229,7 +229,7 @@ void rtp_scheduler_remove_session(RtpScheduler *sched, RtpSession *session)
}
rtp_session_unset_flag(session,RTP_SESSION_IN_SCHEDULER);
- /* delete the bit in the tqmask */
+ /* delete the bit in the mask */
session_set_clr(&sched->all_sessions,session);
rtp_scheduler_unlock(sched);
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
index 36856a99..7b5ad921 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
@@ -60,27 +60,27 @@ void session_set_destroy(SessionSet *set)
gint session_set_and(SessionSet *sched_set, gint maxs, SessionSet *user_set, SessionSet *result_set)
{
- guint32 *tqmask1,*tqmask2,*tqmask3;
+ guint32 *mask1,*mask2,*mask3;
gint i=0;
gint j,ret=0;
- tqmask1=(guint32*)&sched_set->rtpset;
- tqmask2=(guint32*)&user_set->rtpset;
- tqmask3=(guint32*)&result_set->rtpset;
+ mask1=(guint32*)&sched_set->rtpset;
+ mask2=(guint32*)&user_set->rtpset;
+ mask3=(guint32*)&result_set->rtpset;
while(i<maxs+1){
- *tqmask3=(*tqmask1) & (*tqmask2); /* computes the AND between the two masks*/
+ *mask3=(*mask1) & (*mask2); /* computes the AND between the two masks*/
/* and unset the sessions that have been found from the sched_set */
- *tqmask1=(*tqmask1) & (~(*tqmask3));
- if ((*tqmask3)!=0){
+ *mask1=(*mask1) & (~(*mask3));
+ if ((*mask3)!=0){
for (j=0;j<32;j++){
- if ( ((*tqmask3)>>j) & 1){
+ if ( ((*mask3)>>j) & 1){
ret++;
}
}
}
i+=32;
- tqmask1++;
- tqmask2++;
- tqmask3++;
+ mask1++;
+ mask2++;
+ mask3++;
}
//printf("session_set_and: ret=%i\n",ret);
return ret;
@@ -120,8 +120,8 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
rtp_scheduler_lock(sched);
while(1){
- /* computes the SessionSet intersection (in the other words tqmask intersection) between
- the tqmask given by the user and scheduler masks */
+ /* computes the SessionSet intersection (in the other words mask intersection) between
+ the mask given by the user and scheduler masks */
if (recvs!=NULL){
bits=session_set_and(&sched->r_sessions,sched->all_max,recvs,&temp);
if (bits>0){